==================
StashCache Tester
==================

.. image:: https://readthedocs.org/projects/stashcache-tester/badge/?version=latest
   :target: https://readthedocs.org/projects/stashcache-tester/?badge=latest
   :alt: Documentation Status

This is the StashCache Tester.  It creates a set of jobs that will test the
StashCache infrastructure and report results.

`Documentation <http://stashcache-tester.readthedocs.org/>`_
